==> prize-center-api-1.1.8-sources.jar: cn/com/duiba/prize/center/api/dto/projectx/DeductCreditsRequest.java <==
package cn.com.duiba.prize.center.api.dto.projectx;

import java.io.Serializable;

/**
 * @author zhangruofan
 * @date 2019/06/27
 */
public class DeductCreditsRequest implements Serializable {
    private static final long serialVersionUID = -6206695341554832204L;

    private Long appId;
    private Long consumerId;
    private String projectOrderNo;
    private Long credits;
    /**
     * transfer参数可以为空
     */
    private String transfer;
    /**
     * ip可以为空
     */
    private String ip;
    /**
     * 扣积分描述
     * 必传
     */
    private String description;

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getProjectOrderNo() {
        return projectOrderNo;
    }

    public void setProjectOrderNo(String projectOrderNo) {
        this.projectOrderNo = projectOrderNo;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public String getTransfer() {
        return transfer;
    }

    public void setTransfer(String transfer) {
        this.transfer = transfer;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }
}

==> prize-center-api-1.1.24-20231219.073448-1-sources.jar: cn/com/duiba/prize/center/api/dto/projectx/DeductCreditsRequest.java <==
package cn.com.duiba.prize.center.api.dto.projectx;

import java.io.Serializable;

/**
 * @author zhangruofan
 * @date 2019/06/27
 */
public class DeductCreditsRequest implements Serializable {
    private static final long serialVersionUID = -6206695341554832204L;

    private Long appId;
    private Long consumerId;
    private String projectOrderNo;
    private Long credits;
    /**
     * transfer参数可以为空
     */
    private String transfer;
    /**
     * ip可以为空
     */
    private String ip;
    /**
     * 扣积分描述
     * 必传
     */
    private String description;

    /**
     * 项目id
     */
    private String projectId;
    /**
     * 项目名称
     */
    private String projectName;

    public String getProjectId() {
        return projectId;
    }

    public DeductCreditsRequest setProjectId(String projectId) {
        this.projectId = projectId;
        return this;
    }

    public String getProjectName() {
        return projectName;
    }

    public DeductCreditsRequest setProjectName(String projectName) {
        this.projectName = projectName;
        return this;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getProjectOrderNo() {
        return projectOrderNo;
    }

    public void setProjectOrderNo(String projectOrderNo) {
        this.projectOrderNo = projectOrderNo;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public String getTransfer() {
        return transfer;
    }

    public void setTransfer(String transfer) {
        this.transfer = transfer;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }
}
